summaryrefslogtreecommitdiff
path: root/src/qcommon/files.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/qcommon/files.c')
-rw-r--r--src/qcommon/files.c45
1 files changed, 23 insertions, 22 deletions
diff --git a/src/qcommon/files.c b/src/qcommon/files.c
index ebf19b16..1a336de5 100644
--- a/src/qcommon/files.c
+++ b/src/qcommon/files.c
@@ -1,21 +1,22 @@
/*
===========================================================================
Copyright (C) 1999-2005 Id Software, Inc.
+Copyright (C) 2000-2006 Tim Angus
-This file is part of Quake III Arena source code.
+This file is part of Tremulous.
-Quake III Arena source code is free software; you can redistribute it
+Tremulous is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.
-Quake III Arena source code is distributed in the hope that it will be
+Tremulous is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
-along with Quake III Arena source code; if not, write to the Free Software
+along with Tremulous; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
===========================================================================
*/
@@ -69,7 +70,7 @@ along with "home path" and "cd path" for game content.
The "base game" is the directory under the paths where data comes from by default, and
-can be either "baseq3" or "demoq3".
+can be "base".
The "current game" may be the same as the base game, or it may be the name of another
directory under the paths that should be searched for files before looking in the base game.
@@ -96,7 +97,7 @@ automatically restricts where game media can come from to prevent add-ons from w
After the paths are initialized, quake will look for the product.txt file. If not
found and verified, the game will run in restricted mode. In restricted mode, only
files contained in demoq3/pak0.pk3 will be available for loading, and only if the zip header is
-verified to not have been modified. A single exception is made for q3config.cfg. Files
+verified to not have been modified. A single exception is made for autogen.cfg. Files
can still be written out in restricted mode, so screenshots and demos are allowed.
Restricted mode can be tested by setting "+set fs_restrict 1" on the command line, even
if there is a valid product.txt under the basepath or cdpath.
@@ -115,8 +116,8 @@ calls to FS_AddGameDirectory
Additionaly, we search in several subdirectories:
current game is the current mode
base game is a variable to allow mods based on other mods
-(such as baseq3 + missionpack content combination in a mod for instance)
-BASEGAME is the hardcoded base game ("baseq3")
+(such as base + missionpack content combination in a mod for instance)
+BASEGAME is the hardcoded base game ("base")
e.g. the qpath "sound/newstuff/test.wav" would be searched for in the following places:
@@ -184,7 +185,7 @@ Read / write config to floppy option.
Different version coexistance?
-When building a pak file, make sure a q3config.cfg isn't present in it,
+When building a pak file, make sure a autogen.cfg isn't present in it,
or configs will never get loaded from disk!
todo:
@@ -221,9 +222,9 @@ typedef struct fileInPack_s {
} fileInPack_t;
typedef struct {
- char pakFilename[MAX_OSPATH]; // c:\quake3\baseq3\pak0.pk3
+ char pakFilename[MAX_OSPATH]; // /tremulous/base/pak0.pk3
char pakBasename[MAX_OSPATH]; // pak0
- char pakGamename[MAX_OSPATH]; // baseq3
+ char pakGamename[MAX_OSPATH]; // base
unzFile handle; // handle to zip file
int checksum; // regular checksum
int pure_checksum; // checksum for pure
@@ -235,8 +236,8 @@ typedef struct {
} pack_t;
typedef struct {
- char path[MAX_OSPATH]; // c:\quake3
- char gamedir[MAX_OSPATH]; // baseq3
+ char path[MAX_OSPATH];
+ char gamedir[MAX_OSPATH]; // base
} directory_t;
typedef struct searchpath_s {
@@ -2126,7 +2127,7 @@ static char** Sys_ConcatenateFileLists( char **list0, char **list1, char **list2
FS_GetModList
Returns a list of mod directory names
-A mod directory is a peer to baseq3 with a pk3 in it
+A mod directory is a peer to base with a pk3 in it
The directories are searched in base path, cd path and home path
================
*/
@@ -2173,8 +2174,8 @@ int FS_GetModList( char *listbuf, int bufsize ) {
if (bDrop) {
continue;
}
- // we drop "baseq3" "." and ".."
- if (Q_stricmp(name, "baseq3") && Q_stricmpn(name, ".", 1)) {
+ // we drop "base" "." and ".."
+ if (Q_stricmp(name, "base") && Q_stricmpn(name, ".", 1)) {
// now we need to find some .pk3 files to validate the mod
// NOTE TTimo: (actually I'm not sure why .. what if it's a mod under developement with no .pk3?)
// we didn't keep the information when we merged the directory names, as to what OS Path it was found under
@@ -2602,8 +2603,8 @@ qboolean FS_ComparePaks( char *neededpaks, int len, qboolean dlstring ) {
badchecksum = qfalse;
havepak = qfalse;
- // never autodownload any of the id paks
- if ( FS_idPak(fs_serverReferencedPakNames[i], "baseq3") || FS_idPak(fs_serverReferencedPakNames[i], "missionpack") ) {
+ // never autodownload any of the tremulous paks
+ if ( FS_idPak(fs_serverReferencedPakNames[i], "base") ) {
continue;
}
@@ -2814,7 +2815,7 @@ static void FS_Startup( const char *gameName ) {
}
}
- Com_ReadCDKey( "baseq3" );
+ Com_ReadCDKey( "base" );
fs = Cvar_Get ("fs_game", "", CVAR_INIT|CVAR_SYSTEMINFO );
if (fs && fs->string[0] != 0) {
Com_AppendCDKey( fs->string );
@@ -3108,7 +3109,7 @@ const char *FS_ReferencedPakNames( void ) {
info[0] = 0;
// we want to return ALL pk3's from the fs_game path
- // and referenced one's from baseq3
+ // and referenced one's from base
for ( search = fs_searchpaths ; search ; search = search->next ) {
// is the element a pak file?
if ( search->pack ) {
@@ -3337,9 +3338,9 @@ void FS_Restart( int checksumFeed ) {
// bk010116 - new check before safeMode
if ( Q_stricmp(fs_gamedirvar->string, lastValidGame) ) {
// skip the q3config.cfg if "safe" is on the command line
if ( !Com_SafeMode() ) {
- Cbuf_AddText ("exec q3config.cfg\n");
+ Cbuf_AddText ("exec autogen.cfg\n");
}
}
@@ -3337,9 +3338,9 @@ void FS_Restart( int checksumFeed ) {
// bk010116 - new check before safeMode
if ( Q_stricmp(fs_gamedirvar->string, lastValidGame) ) {
- // skip the q3config.cfg if "safe" is on the command line
+ // skip the autogen.cfg if "safe" is on the command line
if ( !Com_SafeMode() ) {